/* Opcode tables for AVR32.
   Copyright 2005, 2006 Atmel Corporation.

   Written by Haavard Skinnemoen, Atmel Norway, <hskinnemoen@atmel.com>

   This file is part of libopcodes.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.  */

#include "bfd.h"

#define AVR32_MAX_OPERANDS	8
#define AVR32_MAX_FIELDS	8

#define AVR32_V1	        (1 << 1)
#define AVR32_SIMD		(1 << 2)
#define AVR32_DSP		(1 << 3)
#define AVR32_RMW		(1 << 4)
#define AVR32_FP		(1 << 16)
#define AVR32_PICO		(1 << 17)

/* Registers we commonly refer to */
#define AVR32_REG_R12		12
#define AVR32_REG_SP		13
#define AVR32_REG_LR		14
#define AVR32_REG_PC		15

struct avr32_ifield
{
  int id;
  unsigned short bitsize;
  unsigned short shift;
  unsigned long mask;

  /* If the value doesn't fit, it will be truncated with no warning */
  void (*insert)(const struct avr32_ifield *, void *, unsigned long);
  void (*extract)(const struct avr32_ifield *, void *, unsigned long *);
};

struct avr32_opcode
{
  int id;
  int size;
  unsigned long value;
  unsigned long mask;
  const struct avr32_syntax *syntax;
  bfd_reloc_code_real_type reloc_type;
  unsigned int nr_fields;
  /* if relaxable, which field is variable, otherwise -1 */
  int var_field;
  const struct avr32_ifield *fields[AVR32_MAX_FIELDS];
};

struct avr32_alias
{
  int id;
  const struct avr32_opcode *opc;
  struct {
    int is_opindex;
    unsigned long value;
  } operand_map[AVR32_MAX_OPERANDS];
};

struct avr32_syntax
{
  int id;
  unsigned long isa_flags;
  const struct avr32_mnemonic *mnemonic;
  int type;
  union {
    const struct avr32_opcode *opc;
    const struct avr32_alias *alias;
  } u;
  const struct avr32_syntax *next;
  /* negative means "vararg" */
  int nr_operands;
  int operand[AVR32_MAX_OPERANDS];
};

#if 0
#define AVR32_ALIAS_MAKE_CONST(val) ((val) | 0x80000000UL)
#define AVR32_ALIAS_IS_CONST(mapval) (((mapval) & 0x80000000UL) != 0)
#define AVR32_ALIAS_GET_CONST(mapval) ((mapval) & ~0x80000000UL)
#endif

struct avr32_mnemonic
{
  int id;
  const char *name;
  const struct avr32_syntax *syntax;
};

extern const struct avr32_ifield avr32_ifield_table[];
extern struct avr32_opcode avr32_opc_table[];
extern const struct avr32_syntax avr32_syntax_table[];
extern const struct avr32_alias avr32_alias_table[];
extern const struct avr32_mnemonic avr32_mnemonic_table[];

extern void avr32_insert_simple(const struct avr32_ifield *field,
				void *buf, unsigned long value);
extern void avr32_insert_bit5c(const struct avr32_ifield *field,
			       void *buf, unsigned long value);
extern void avr32_insert_k10(const struct avr32_ifield *field,
			     void *buf, unsigned long value);
extern void avr32_insert_k21(const struct avr32_ifield *field,
			     void *buf, unsigned long value);
extern void avr32_insert_cpop(const struct avr32_ifield *field,
			      void *buf, unsigned long value);
extern void avr32_insert_k12cp(const struct avr32_ifield *field,
			       void *buf, unsigned long value);

extern void avr32_extract_simple(const struct avr32_ifield *field,
				 void *buf, unsigned long *value);
extern void avr32_extract_bit5c(const struct avr32_ifield *field,
				void *buf, unsigned long *value);
extern void avr32_extract_k10(const struct avr32_ifield *field,
			      void *buf, unsigned long *value);
extern void avr32_extract_k21(const struct avr32_ifield *field,
			      void *buf, unsigned long *value);
extern void avr32_extract_cpop(const struct avr32_ifield *field,
			       void *buf, unsigned long *value);
extern void avr32_extract_k12cp(const struct avr32_ifield *field,
				void *buf, unsigned long *value);

enum avr32_operand_type
{
  AVR32_OPERAND_INTREG,		/* just a register */
  AVR32_OPERAND_INTREG_PREDEC,	/* register with pre-decrement */
  AVR32_OPERAND_INTREG_POSTINC,	/* register with post-increment */
  AVR32_OPERAND_INTREG_LSL,	/* register with left shift */
  AVR32_OPERAND_INTREG_LSR,	/* register with right shift */
  AVR32_OPERAND_INTREG_BSEL,	/* register with byte selector */
  AVR32_OPERAND_INTREG_HSEL,	/* register with halfword selector */
  AVR32_OPERAND_INTREG_SDISP,	/* Rp[signed disp] */
  AVR32_OPERAND_INTREG_SDISP_H,	/* Rp[signed hword-aligned disp] */
  AVR32_OPERAND_INTREG_SDISP_W,	/* Rp[signed word-aligned disp] */
  AVR32_OPERAND_INTREG_UDISP,	/* Rp[unsigned disp] */
  AVR32_OPERAND_INTREG_UDISP_H,	/* Rp[unsigned hword-aligned disp] */
  AVR32_OPERAND_INTREG_UDISP_W, /* Rp[unsigned word-aligned disp] */
  AVR32_OPERAND_INTREG_INDEX,	/* Rp[Ri << sa] */
  AVR32_OPERAND_INTREG_XINDEX,	/* Rp[Ri:bytesel << 2] */
  AVR32_OPERAND_DWREG,		/* Even-numbered register */
  AVR32_OPERAND_PC_UDISP_W,	/* PC[unsigned word-aligned disp] or label */
  AVR32_OPERAND_SP,		/* Just SP */
  AVR32_OPERAND_SP_UDISP_W,	/* SP[unsigned word-aligned disp] */
  AVR32_OPERAND_CPNO,
  AVR32_OPERAND_CPREG,
  AVR32_OPERAND_CPREG_D,
  AVR32_OPERAND_UNSIGNED_CONST,
  AVR32_OPERAND_UNSIGNED_CONST_W,
  AVR32_OPERAND_SIGNED_CONST,
  AVR32_OPERAND_SIGNED_CONST_W,
  AVR32_OPERAND_JMPLABEL,
  AVR32_OPERAND_UNSIGNED_NUMBER,
  AVR32_OPERAND_UNSIGNED_NUMBER_W,
  AVR32_OPERAND_REGLIST8,
  AVR32_OPERAND_REGLIST9,
  AVR32_OPERAND_REGLIST16,
  AVR32_OPERAND_REGLIST_LDM,
  AVR32_OPERAND_REGLIST_CP8,
  AVR32_OPERAND_REGLIST_CPD8,
  AVR32_OPERAND_RETVAL,
  AVR32_OPERAND_MCALL,
  AVR32_OPERAND_JOSPINC,
  AVR32_OPERAND_COH,
  AVR32_OPERAND_FPREG_S,
  AVR32_OPERAND_FPREG_D,
  AVR32_OPERAND_PICO_REG_W,
  AVR32_OPERAND_PICO_REG_D,
  AVR32_OPERAND_PICO_REGLIST_W,
  AVR32_OPERAND_PICO_REGLIST_D,
  AVR32_OPERAND_PICO_OUT0,
  AVR32_OPERAND_PICO_OUT1,
  AVR32_OPERAND_PICO_OUT2,
  AVR32_OPERAND__END_
};
#define AVR32_OPERAND_UNKNOWN AVR32_OPERAND__END_
#define AVR32_NR_OPERANDS AVR32_OPERAND__END_

enum avr32_ifield_type
{
  AVR32_IFIELD_RX,
  AVR32_IFIELD_RY,
  AVR32_IFIELD_COND4C,
  AVR32_IFIELD_K8C,
  AVR32_IFIELD_K7C,
  AVR32_IFIELD_K5C,
  AVR32_IFIELD_K3,
  AVR32_IFIELD_RY_DW,
  AVR32_IFIELD_COND4E,
  AVR32_IFIELD_K8E,
  AVR32_IFIELD_BIT5C,
  AVR32_IFIELD_COND3,
  AVR32_IFIELD_K10,
  AVR32_IFIELD_POPM,
  AVR32_IFIELD_K2,
  AVR32_IFIELD_RD_E,
  AVR32_IFIELD_RD_DW,
  AVR32_IFIELD_X,
  AVR32_IFIELD_Y,
  AVR32_IFIELD_X2,
  AVR32_IFIELD_Y2,
  AVR32_IFIELD_K5E,
  AVR32_IFIELD_PART2,
  AVR32_IFIELD_PART1,
  AVR32_IFIELD_K16,
  AVR32_IFIELD_CACHEOP,
  AVR32_IFIELD_K11,
  AVR32_IFIELD_K21,
  AVR32_IFIELD_CPOP,
  AVR32_IFIELD_CPNO,
  AVR32_IFIELD_CRD_RI,
  AVR32_IFIELD_CRX,
  AVR32_IFIELD_CRY,
  AVR32_IFIELD_K7E,
  AVR32_IFIELD_CRD_DW,
  AVR32_IFIELD_PART1_K12,
  AVR32_IFIELD_PART2_K12,
  AVR32_IFIELD_K12,
  AVR32_IFIELD_S5,
  AVR32_IFIELD_K5E2,
  AVR32_IFIELD_K4,
  AVR32_IFIELD_COND4E2,
  AVR32_IFIELD_K8E2,
  AVR32_IFIELD_K6,
  AVR32_IFIELD_MEM15,
  AVR32_IFIELD_MEMB5,
  AVR32_IFIELD_W,
  AVR32_IFIELD_CM_HL,
  AVR32_IFIELD_K12CP,
  AVR32_IFIELD__END_,
};
#define AVR32_NR_IFIELDS AVR32_IFIELD__END_

enum avr32_opc_type
{
  AVR32_OPC_ABS,
  AVR32_OPC_ACALL,
  AVR32_OPC_ACR,
  AVR32_OPC_ADC,
  AVR32_OPC_ADD1,
  AVR32_OPC_ADD2,
  AVR32_OPC_ADDABS,
  AVR32_OPC_ADDHH_W,
  AVR32_OPC_AND1,
  AVR32_OPC_AND2,
  AVR32_OPC_AND3,
  AVR32_OPC_ANDH,
  AVR32_OPC_ANDH_COH,
  AVR32_OPC_ANDL,
  AVR32_OPC_ANDL_COH,
  AVR32_OPC_ANDN,
  AVR32_OPC_ASR1,
  AVR32_OPC_ASR3,
  AVR32_OPC_ASR2,
  AVR32_OPC_BLD,
  AVR32_OPC_BREQ1,
  AVR32_OPC_BRNE1,
  AVR32_OPC_BRCC1,
  AVR32_OPC_BRCS1,
  AVR32_OPC_BRGE1,
  AVR32_OPC_BRLT1,
  AVR32_OPC_BRMI1,
  AVR32_OPC_BRPL1,
  AVR32_OPC_BREQ2,
  AVR32_OPC_BRNE2,
  AVR32_OPC_BRCC2,
  AVR32_OPC_BRCS2,
  AVR32_OPC_BRGE2,
  AVR32_OPC_BRLT2,
  AVR32_OPC_BRMI2,
  AVR32_OPC_BRPL2,
  AVR32_OPC_BRLS,
  AVR32_OPC_BRGT,
  AVR32_OPC_BRLE,
  AVR32_OPC_BRHI,
  AVR32_OPC_BRVS,
  AVR32_OPC_BRVC,
  AVR32_OPC_BRQS,
  AVR32_OPC_BRAL,
  AVR32_OPC_BREAKPOINT,
  AVR32_OPC_BREV,
  AVR32_OPC_BST,
  AVR32_OPC_CACHE,
  AVR32_OPC_CASTS_B,
  AVR32_OPC_CASTS_H,
  AVR32_OPC_CASTU_B,
  AVR32_OPC_CASTU_H,
  AVR32_OPC_CBR,
  AVR32_OPC_CLZ,
  AVR32_OPC_COM,
  AVR32_OPC_COP,
  AVR32_OPC_CP_B,
  AVR32_OPC_CP_H,
  AVR32_OPC_CP_W1,
  AVR32_OPC_CP_W2,
  AVR32_OPC_CP_W3,
  AVR32_OPC_CPC1,
  AVR32_OPC_CPC2,
  AVR32_OPC_CSRF,
  AVR32_OPC_CSRFCZ,
  AVR32_OPC_DIVS,
  AVR32_OPC_DIVU,
  AVR32_OPC_EOR1,
  AVR32_OPC_EOR2,
  AVR32_OPC_EOR3,
  AVR32_OPC_EORL,
  AVR32_OPC_EORH,
  AVR32_OPC_FRS,
  AVR32_OPC_ICALL,
  AVR32_OPC_INCJOSP,
  AVR32_OPC_LD_D1,
  AVR32_OPC_LD_D2,
  AVR32_OPC_LD_D3,
  AVR32_OPC_LD_D5,
  AVR32_OPC_LD_D4,
  AVR32_OPC_LD_SB2,
  AVR32_OPC_LD_SB1,
  AVR32_OPC_LD_UB1,
  AVR32_OPC_LD_UB2,
  AVR32_OPC_LD_UB5,
  AVR32_OPC_LD_UB3,
  AVR32_OPC_LD_UB4,
  AVR32_OPC_LD_SH1,
  AVR32_OPC_LD_SH2,
  AVR32_OPC_LD_SH5,
  AVR32_OPC_LD_SH3,
  AVR32_OPC_LD_SH4,
  AVR32_OPC_LD_UH1,
  AVR32_OPC_LD_UH2,
  AVR32_OPC_LD_UH5,
  AVR32_OPC_LD_UH3,
  AVR32_OPC_LD_UH4,
  AVR32_OPC_LD_W1,
  AVR32_OPC_LD_W2,
  AVR32_OPC_LD_W5,
  AVR32_OPC_LD_W6,
  AVR32_OPC_LD_W3,
  AVR32_OPC_LD_W4,
  AVR32_OPC_LDC_D1,
  AVR32_OPC_LDC_D2,
  AVR32_OPC_LDC_D3,
  AVR32_OPC_LDC_W1,
  AVR32_OPC_LDC_W2,
  AVR32_OPC_LDC_W3,
  AVR32_OPC_LDC0_D,
  AVR32_OPC_LDC0_W,
  AVR32_OPC_LDCM_D,
  AVR32_OPC_LDCM_D_PU,
  AVR32_OPC_LDCM_W,
  AVR32_OPC_LDCM_W_PU,
  AVR32_OPC_LDDPC,
  AVR32_OPC_LDDPC_EXT,
  AVR32_OPC_LDDSP,
  AVR32_OPC_LDINS_B,
  AVR32_OPC_LDINS_H,
  AVR32_OPC_LDM,
  AVR32_OPC_LDMTS,
  AVR32_OPC_LDMTS_PU,
  AVR32_OPC_LDSWP_SH,
  AVR32_OPC_LDSWP_UH,
  AVR32_OPC_LDSWP_W,
  AVR32_OPC_LSL1,
  AVR32_OPC_LSL3,
  AVR32_OPC_LSL2,
  AVR32_OPC_LSR1,
  AVR32_OPC_LSR3,
  AVR32_OPC_LSR2,
  AVR32_OPC_MAC,
  AVR32_OPC_MACHH_D,
  AVR32_OPC_MACHH_W,
  AVR32_OPC_MACS_D,
  AVR32_OPC_MACSATHH_W,
  AVR32_OPC_MACUD,
  AVR32_OPC_MACWH_D,
  AVR32_OPC_MAX,
  AVR32_OPC_MCALL,
  AVR32_OPC_MFDR,
  AVR32_OPC_MFSR,
  AVR32_OPC_MIN,
  AVR32_OPC_MOV3,
  AVR32_OPC_MOV1,
  AVR32_OPC_MOV2,
  AVR32_OPC_MOVEQ1,
  AVR32_OPC_MOVNE1,
  AVR32_OPC_MOVCC1,
  AVR32_OPC_MOVCS1,
  AVR32_OPC_MOVGE1,
  AVR32_OPC_MOVLT1,
  AVR32_OPC_MOVMI1,
  AVR32_OPC_MOVPL1,
  AVR32_OPC_MOVLS1,
  AVR32_OPC_MOVGT1,
  AVR32_OPC_MOVLE1,
  AVR32_OPC_MOVHI1,
  AVR32_OPC_MOVVS1,
  AVR32_OPC_MOVVC1,
  AVR32_OPC_MOVQS1,
  AVR32_OPC_MOVAL1,
  AVR32_OPC_MOVEQ2,
  AVR32_OPC_MOVNE2,
  AVR32_OPC_MOVCC2,
  AVR32_OPC_MOVCS2,
  AVR32_OPC_MOVGE2,
  AVR32_OPC_MOVLT2,
  AVR32_OPC_MOVMI2,
  AVR32_OPC_MOVPL2,
  AVR32_OPC_MOVLS2,
  AVR32_OPC_MOVGT2,
  AVR32_OPC_MOVLE2,
  AVR32_OPC_MOVHI2,
  AVR32_OPC_MOVVS2,
  AVR32_OPC_MOVVC2,
  AVR32_OPC_MOVQS2,
  AVR32_OPC_MOVAL2,
  AVR32_OPC_MTDR,
  AVR32_OPC_MTSR,
  AVR32_OPC_MUL1,
  AVR32_OPC_MUL2,
  AVR32_OPC_MUL3,
  AVR32_OPC_MULHH_W,
  AVR32_OPC_MULNHH_W,
  AVR32_OPC_MULNWH_D,
  AVR32_OPC_MULSD,
  AVR32_OPC_MULSATHH_H,
  AVR32_OPC_MULSATHH_W,
  AVR32_OPC_MULSATRNDHH_H,
  AVR32_OPC_MULSATRNDWH_W,
  AVR32_OPC_MULSATWH_W,
  AVR32_OPC_MULU_D,
  AVR32_OPC_MULWH_D,
  AVR32_OPC_MUSFR,
  AVR32_OPC_MUSTR,
  AVR32_OPC_MVCR_D,
  AVR32_OPC_MVCR_W,
  AVR32_OPC_MVRC_D,
  AVR32_OPC_MVRC_W,
  AVR32_OPC_NEG,
  AVR32_OPC_NOP,
  AVR32_OPC_OR1,
  AVR32_OPC_OR2,
  AVR32_OPC_OR3,
  AVR32_OPC_ORH,
  AVR32_OPC_ORL,
  AVR32_OPC_PABS_SB,
  AVR32_OPC_PABS_SH,
  AVR32_OPC_PACKSH_SB,
  AVR32_OPC_PACKSH_UB,
  AVR32_OPC_PACKW_SH,
  AVR32_OPC_PADD_B,
  AVR32_OPC_PADD_H,
  AVR32_OPC_PADDH_SH,
  AVR32_OPC_PADDH_UB,
  AVR32_OPC_PADDS_SB,
  AVR32_OPC_PADDS_SH,
  AVR32_OPC_PADDS_UB,
  AVR32_OPC_PADDS_UH,
  AVR32_OPC_PADDSUB_H,
  AVR32_OPC_PADDSUBH_SH,
  AVR32_OPC_PADDSUBS_SH,
  AVR32_OPC_PADDSUBS_UH,
  AVR32_OPC_PADDX_H,
  AVR32_OPC_PADDXH_SH,
  AVR32_OPC_PADDXS_SH,
  AVR32_OPC_PADDXS_UH,
  AVR32_OPC_PASR_B,
  AVR32_OPC_PASR_H,
  AVR32_OPC_PAVG_SH,
  AVR32_OPC_PAVG_UB,
  AVR32_OPC_PLSL_B,
  AVR32_OPC_PLSL_H,
  AVR32_OPC_PLSR_B,
  AVR32_OPC_PLSR_H,
  AVR32_OPC_PMAX_SH,
  AVR32_OPC_PMAX_UB,
  AVR32_OPC_PMIN_SH,
  AVR32_OPC_PMIN_UB,
  AVR32_OPC_POPJC,
  AVR32_OPC_POPM,
  AVR32_OPC_POPM_E,
  AVR32_OPC_PREF,
  AVR32_OPC_PSAD,
  AVR32_OPC_PSUB_B,
  AVR32_OPC_PSUB_H,
  AVR32_OPC_PSUBADD_H,
  AVR32_OPC_PSUBADDH_SH,
  AVR32_OPC_PSUBADDS_SH,
  AVR32_OPC_PSUBADDS_UH,
  AVR32_OPC_PSUBH_SH,
  AVR32_OPC_PSUBH_UB,
  AVR32_OPC_PSUBS_SB,
  AVR32_OPC_PSUBS_SH,
  AVR32_OPC_PSUBS_UB,
  AVR32_OPC_PSUBS_UH,
  AVR32_OPC_PSUBX_H,
  AVR32_OPC_PSUBXH_SH,
  AVR32_OPC_PSUBXS_SH,
  AVR32_OPC_PSUBXS_UH,
  AVR32_OPC_PUNPCKSB_H,
  AVR32_OPC_PUNPCKUB_H,
  AVR32_OPC_PUSHJC,
  AVR32_OPC_PUSHM,
  AVR32_OPC_PUSHM_E,
  AVR32_OPC_RCALL1,
  AVR32_OPC_RCALL2,
  AVR32_OPC_RETEQ,
  AVR32_OPC_RETNE,
  AVR32_OPC_RETCC,
  AVR32_OPC_RETCS,
  AVR32_OPC_RETGE,
  AVR32_OPC_RETLT,
  AVR32_OPC_RETMI,
  AVR32_OPC_RETPL,
  AVR32_OPC_RETLS,
  AVR32_OPC_RETGT,
  AVR32_OPC_RETLE,
  AVR32_OPC_RETHI,
  AVR32_OPC_RETVS,
  AVR32_OPC_RETVC,
  AVR32_OPC_RETQS,
  AVR32_OPC_RETAL,
  AVR32_OPC_RETD,
  AVR32_OPC_RETE,
  AVR32_OPC_RETJ,
  AVR32_OPC_RETS,
  AVR32_OPC_RJMP,
  AVR32_OPC_ROL,
  AVR32_OPC_ROR,
  AVR32_OPC_RSUB1,
  AVR32_OPC_RSUB2,
  AVR32_OPC_SATADD_H,
  AVR32_OPC_SATADD_W,
  AVR32_OPC_SATRNDS,
  AVR32_OPC_SATRNDU,
  AVR32_OPC_SATS,
  AVR32_OPC_SATSUB_H,
  AVR32_OPC_SATSUB_W1,
  AVR32_OPC_SATSUB_W2,
  AVR32_OPC_SATU,
  AVR32_OPC_SBC,
  AVR32_OPC_SBR,
  AVR32_OPC_SCALL,
  AVR32_OPC_SCR,
  AVR32_OPC_SLEEP,
  AVR32_OPC_SREQ,
  AVR32_OPC_SRNE,
  AVR32_OPC_SRCC,
  AVR32_OPC_SRCS,
  AVR32_OPC_SRGE,
  AVR32_OPC_SRLT,
  AVR32_OPC_SRMI,
  AVR32_OPC_SRPL,
  AVR32_OPC_SRLS,
  AVR32_OPC_SRGT,
  AVR32_OPC_SRLE,
  AVR32_OPC_SRHI,
  AVR32_OPC_SRVS,
  AVR32_OPC_SRVC,
  AVR32_OPC_SRQS,
  AVR32_OPC_SRAL,
  AVR32_OPC_SSRF,
  AVR32_OPC_ST_B1,
  AVR32_OPC_ST_B2,
  AVR32_OPC_ST_B5,
  AVR32_OPC_ST_B3,
  AVR32_OPC_ST_B4,
  AVR32_OPC_ST_D1,
  AVR32_OPC_ST_D2,
  AVR32_OPC_ST_D3,
  AVR32_OPC_ST_D5,
  AVR32_OPC_ST_D4,
  AVR32_OPC_ST_H1,
  AVR32_OPC_ST_H2,
  AVR32_OPC_ST_H5,
  AVR32_OPC_ST_H3,
  AVR32_OPC_ST_H4,
  AVR32_OPC_ST_W1,
  AVR32_OPC_ST_W2,
  AVR32_OPC_ST_W5,
  AVR32_OPC_ST_W3,
  AVR32_OPC_ST_W4,
  AVR32_OPC_STC_D1,
  AVR32_OPC_STC_D2,
  AVR32_OPC_STC_D3,
  AVR32_OPC_STC_W1,
  AVR32_OPC_STC_W2,
  AVR32_OPC_STC_W3,
  AVR32_OPC_STC0_D,
  AVR32_OPC_STC0_W,
  AVR32_OPC_STCM_D,
  AVR32_OPC_STCM_D_PU,
  AVR32_OPC_STCM_W,
  AVR32_OPC_STCM_W_PU,
  AVR32_OPC_STCOND,
  AVR32_OPC_STDSP,
  AVR32_OPC_STHH_W2,
  AVR32_OPC_STHH_W1,
  AVR32_OPC_STM,
  AVR32_OPC_STM_PU,
  AVR32_OPC_STMTS,
  AVR32_OPC_STMTS_PU,
  AVR32_OPC_STSWP_H,
  AVR32_OPC_STSWP_W,
  AVR32_OPC_SUB1,
  AVR32_OPC_SUB2,
  AVR32_OPC_SUB5,
  AVR32_OPC_SUB3_SP,
  AVR32_OPC_SUB3,
  AVR32_OPC_SUB4,
  AVR32_OPC_SUBEQ,
  AVR32_OPC_SUBNE,
  AVR32_OPC_SUBCC,
  AVR32_OPC_SUBCS,
  AVR32_OPC_SUBGE,
  AVR32_OPC_SUBLT,
  AVR32_OPC_SUBMI,
  AVR32_OPC_SUBPL,
  AVR32_OPC_SUBLS,
  AVR32_OPC_SUBGT,
  AVR32_OPC_SUBLE,
  AVR32_OPC_SUBHI,
  AVR32_OPC_SUBVS,
  AVR32_OPC_SUBVC,
  AVR32_OPC_SUBQS,
  AVR32_OPC_SUBAL,
  AVR32_OPC_SUBFEQ,
  AVR32_OPC_SUBFNE,
  AVR32_OPC_SUBFCC,
  AVR32_OPC_SUBFCS,
  AVR32_OPC_SUBFGE,
  AVR32_OPC_SUBFLT,
  AVR32_OPC_SUBFMI,
  AVR32_OPC_SUBFPL,
  AVR32_OPC_SUBFLS,
  AVR32_OPC_SUBFGT,
  AVR32_OPC_SUBFLE,
  AVR32_OPC_SUBFHI,
  AVR32_OPC_SUBFVS,
  AVR32_OPC_SUBFVC,
  AVR32_OPC_SUBFQS,
  AVR32_OPC_SUBFAL,
  AVR32_OPC_SUBHH_W,
  AVR32_OPC_SWAP_B,
  AVR32_OPC_SWAP_BH,
  AVR32_OPC_SWAP_H,
  AVR32_OPC_SYNC,
  AVR32_OPC_TLBR,
  AVR32_OPC_TLBS,
  AVR32_OPC_TLBW,
  AVR32_OPC_TNBZ,
  AVR32_OPC_TST,
  AVR32_OPC_XCHG,
  AVR32_OPC_MEMC,
  AVR32_OPC_MEMS,
  AVR32_OPC_MEMT,
  AVR32_OPC_BFEXTS,
  AVR32_OPC_BFEXTU,
  AVR32_OPC_BFINS,
  AVR32_OPC__END_
};
#define AVR32_NR_OPCODES AVR32_OPC__END_

enum avr32_syntax_type
{
  AVR32_SYNTAX_ABS,
  AVR32_SYNTAX_ACALL,
  AVR32_SYNTAX_ACR,
  AVR32_SYNTAX_ADC,
  AVR32_SYNTAX_ADD1,
  AVR32_SYNTAX_ADD2,
  AVR32_SYNTAX_ADDABS,
  AVR32_SYNTAX_ADDHH_W,
  AVR32_SYNTAX_AND1,
  AVR32_SYNTAX_AND2,
  AVR32_SYNTAX_AND3,
  AVR32_SYNTAX_ANDH,
  AVR32_SYNTAX_ANDH_COH,
  AVR32_SYNTAX_ANDL,
  AVR32_SYNTAX_ANDL_COH,
  AVR32_SYNTAX_ANDN,
  AVR32_SYNTAX_ASR1,
  AVR32_SYNTAX_ASR3,
  AVR32_SYNTAX_ASR2,
  AVR32_SYNTAX_BFEXTS,
  AVR32_SYNTAX_BFEXTU,
  AVR32_SYNTAX_BFINS,
  AVR32_SYNTAX_BLD,
  AVR32_SYNTAX_BREQ1,
  AVR32_SYNTAX_BRNE1,
  AVR32_SYNTAX_BRCC1,
  AVR32_SYNTAX_BRCS1,
  AVR32_SYNTAX_BRGE1,
  AVR32_SYNTAX_BRLT1,
  AVR32_SYNTAX_BRMI1,
  AVR32_SYNTAX_BRPL1,
  AVR32_SYNTAX_BRHS1,
  AVR32_SYNTAX_BRLO1,
  AVR32_SYNTAX_BREQ2,
  AVR32_SYNTAX_BRNE2,
  AVR32_SYNTAX_BRCC2,
  AVR32_SYNTAX_BRCS2,
  AVR32_SYNTAX_BRGE2,
  AVR32_SYNTAX_BRLT2,
  AVR32_SYNTAX_BRMI2,
  AVR32_SYNTAX_BRPL2,
  AVR32_SYNTAX_BRLS,
  AVR32_SYNTAX_BRGT,
  AVR32_SYNTAX_BRLE,
  AVR32_SYNTAX_BRHI,
  AVR32_SYNTAX_BRVS,
  AVR32_SYNTAX_BRVC,
  AVR32_SYNTAX_BRQS,
  AVR32_SYNTAX_BRAL,
  AVR32_SYNTAX_BRHS2,
  AVR32_SYNTAX_BRLO2,
  AVR32_SYNTAX_BREAKPOINT,
  AVR32_SYNTAX_BREV,
  AVR32_SYNTAX_BST,
  AVR32_SYNTAX_CACHE,
  AVR32_SYNTAX_CASTS_B,
  AVR32_SYNTAX_CASTS_H,
  AVR32_SYNTAX_CASTU_B,
  AVR32_SYNTAX_CASTU_H,
  AVR32_SYNTAX_CBR,
  AVR32_SYNTAX_CLZ,
  AVR32_SYNTAX_COM,
  AVR32_SYNTAX_COP,
  AVR32_SYNTAX_CP_B,
  AVR32_SYNTAX_CP_H,
  AVR32_SYNTAX_CP_W1,
  AVR32_SYNTAX_CP_W2,
  AVR32_SYNTAX_CP_W3,
  AVR32_SYNTAX_CPC1,
  AVR32_SYNTAX_CPC2,
  AVR32_SYNTAX_CSRF,
  AVR32_SYNTAX_CSRFCZ,
  AVR32_SYNTAX_DIVS,
  AVR32_SYNTAX_DIVU,
  AVR32_SYNTAX_EOR1,
  AVR32_SYNTAX_EOR2,
  AVR32_SYNTAX_EOR3,
  AVR32_SYNTAX_EORL,
  AVR32_SYNTAX_EORH,
  AVR32_SYNTAX_FRS,
  AVR32_SYNTAX_ICALL,
  AVR32_SYNTAX_INCJOSP,
  AVR32_SYNTAX_LD_D1,
  AVR32_SYNTAX_LD_D2,
  AVR32_SYNTAX_LD_D3,
  AVR32_SYNTAX_LD_D5,
  AVR32_SYNTAX_LD_D4,
  AVR32_SYNTAX_LD_SB2,
  AVR32_SYNTAX_LD_SB1,
  AVR32_SYNTAX_LD_UB1,
  AVR32_SYNTAX_LD_UB2,
  AVR32_SYNTAX_LD_UB5,
  AVR32_SYNTAX_LD_UB3,
  AVR32_SYNTAX_LD_UB4,
  AVR32_SYNTAX_LD_SH1,
  AVR32_SYNTAX_LD_SH2,
  AVR32_SYNTAX_LD_SH5,
  AVR32_SYNTAX_LD_SH3,
  AVR32_SYNTAX_LD_SH4,
  AVR32_SYNTAX_LD_UH1,
  AVR32_SYNTAX_LD_UH2,
  AVR32_SYNTAX_LD_UH5,
  AVR32_SYNTAX_LD_UH3,
  AVR32_SYNTAX_LD_UH4,
  AVR32_SYNTAX_LD_W1,
  AVR32_SYNTAX_LD_W2,
  AVR32_SYNTAX_LD_W5,
  AVR32_SYNTAX_LD_W6,
  AVR32_SYNTAX_LD_W3,
  AVR32_SYNTAX_LD_W4,
  AVR32_SYNTAX_LDC_D1,
  AVR32_SYNTAX_LDC_D2,
  AVR32_SYNTAX_LDC_D3,
  AVR32_SYNTAX_LDC_W1,
  AVR32_SYNTAX_LDC_W2,
  AVR32_SYNTAX_LDC_W3,
  AVR32_SYNTAX_LDC0_D,
  AVR32_SYNTAX_LDC0_W,
  AVR32_SYNTAX_LDCM_D,
  AVR32_SYNTAX_LDCM_D_PU,
  AVR32_SYNTAX_LDCM_W,
  AVR32_SYNTAX_LDCM_W_PU,
  AVR32_SYNTAX_LDDPC,
  AVR32_SYNTAX_LDDPC_EXT,
  AVR32_SYNTAX_LDDSP,
  AVR32_SYNTAX_LDINS_B,
  AVR32_SYNTAX_LDINS_H,
  AVR32_SYNTAX_LDM,
  AVR32_SYNTAX_LDMTS,
  AVR32_SYNTAX_LDMTS_PU,
  AVR32_SYNTAX_LDSWP_SH,
  AVR32_SYNTAX_LDSWP_UH,
  AVR32_SYNTAX_LDSWP_W,
  AVR32_SYNTAX_LSL1,
  AVR32_SYNTAX_LSL3,
  AVR32_SYNTAX_LSL2,
  AVR32_SYNTAX_LSR1,
  AVR32_SYNTAX_LSR3,
  AVR32_SYNTAX_LSR2,
  AVR32_SYNTAX_MAC,
  AVR32_SYNTAX_MACHH_D,
  AVR32_SYNTAX_MACHH_W,
  AVR32_SYNTAX_MACS_D,
  AVR32_SYNTAX_MACSATHH_W,
  AVR32_SYNTAX_MACUD,
  AVR32_SYNTAX_MACWH_D,
  AVR32_SYNTAX_MAX,
  AVR32_SYNTAX_MCALL,
  AVR32_SYNTAX_MFDR,
  AVR32_SYNTAX_MFSR,
  AVR32_SYNTAX_MIN,
  AVR32_SYNTAX_MOV3,
  AVR32_SYNTAX_MOV1,
  AVR32_SYNTAX_MOV2,
  AVR32_SYNTAX_MOVEQ1,
  AVR32_SYNTAX_MOVNE1,
  AVR32_SYNTAX_MOVCC1,
  AVR32_SYNTAX_MOVCS1,
  AVR32_SYNTAX_MOVGE1,
  AVR32_SYNTAX_MOVLT1,
  AVR32_SYNTAX_MOVMI1,
  AVR32_SYNTAX_MOVPL1,
  AVR32_SYNTAX_MOVLS1,
  AVR32_SYNTAX_MOVGT1,
  AVR32_SYNTAX_MOVLE1,
  AVR32_SYNTAX_MOVHI1,
  AVR32_SYNTAX_MOVVS1,
  AVR32_SYNTAX_MOVVC1,
  AVR32_SYNTAX_MOVQS1,
  AVR32_SYNTAX_MOVAL1,
  AVR32_SYNTAX_MOVHS1,
  AVR32_SYNTAX_MOVLO1,
  AVR32_SYNTAX_MOVEQ2,
  AVR32_SYNTAX_MOVNE2,
  AVR32_SYNTAX_MOVCC2,
  AVR32_SYNTAX_MOVCS2,
  AVR32_SYNTAX_MOVGE2,
  AVR32_SYNTAX_MOVLT2,
  AVR32_SYNTAX_MOVMI2,
  AVR32_SYNTAX_MOVPL2,
  AVR32_SYNTAX_MOVLS2,
  AVR32_SYNTAX_MOVGT2,
  AVR32_SYNTAX_MOVLE2,
  AVR32_SYNTAX_MOVHI2,
  AVR32_SYNTAX_MOVVS2,
  AVR32_SYNTAX_MOVVC2,
  AVR32_SYNTAX_MOVQS2,
  AVR32_SYNTAX_MOVAL2,
  AVR32_SYNTAX_MOVHS2,
  AVR32_SYNTAX_MOVLO2,
  AVR32_SYNTAX_MTDR,
  AVR32_SYNTAX_MTSR,
  AVR32_SYNTAX_MUL1,
  AVR32_SYNTAX_MUL2,
  AVR32_SYNTAX_MUL3,
  AVR32_SYNTAX_MULHH_W,
  AVR32_SYNTAX_MULNHH_W,
  AVR32_SYNTAX_MULNWH_D,
  AVR32_SYNTAX_MULSD,
  AVR32_SYNTAX_MULSATHH_H,
  AVR32_SYNTAX_MULSATHH_W,
  AVR32_SYNTAX_MULSATRNDHH_H,
  AVR32_SYNTAX_MULSATRNDWH_W,
  AVR32_SYNTAX_MULSATWH_W,
  AVR32_SYNTAX_MULU_D,
  AVR32_SYNTAX_MULWH_D,
  AVR32_SYNTAX_MUSFR,
  AVR32_SYNTAX_MUSTR,
  AVR32_SYNTAX_MVCR_D,
  AVR32_SYNTAX_MVCR_W,
  AVR32_SYNTAX_MVRC_D,
  AVR32_SYNTAX_MVRC_W,
  AVR32_SYNTAX_NEG,
  AVR32_SYNTAX_NOP,
  AVR32_SYNTAX_OR1,
  AVR32_SYNTAX_OR2,
  AVR32_SYNTAX_OR3,
  AVR32_SYNTAX_ORH,
  AVR32_SYNTAX_ORL,
  AVR32_SYNTAX_PABS_SB,
  AVR32_SYNTAX_PABS_SH,
  AVR32_SYNTAX_PACKSH_SB,
  AVR32_SYNTAX_PACKSH_UB,
  AVR32_SYNTAX_PACKW_SH,
  AVR32_SYNTAX_PADD_B,
  AVR32_SYNTAX_PADD_H,
  AVR32_SYNTAX_PADDH_SH,
  AVR32_SYNTAX_PADDH_UB,
  AVR32_SYNTAX_PADDS_SB,
  AVR32_SYNTAX_PADDS_SH,
  AVR32_SYNTAX_PADDS_UB,
  AVR32_SYNTAX_PADDS_UH,
  AVR32_SYNTAX_PADDSUB_H,
  AVR32_SYNTAX_PADDSUBH_SH,
  AVR32_SYNTAX_PADDSUBS_SH,
  AVR32_SYNTAX_PADDSUBS_UH,
  AVR32_SYNTAX_PADDX_H,
  AVR32_SYNTAX_PADDXH_SH,
  AVR32_SYNTAX_PADDXS_SH,
  AVR32_SYNTAX_PADDXS_UH,
  AVR32_SYNTAX_PASR_B,
  AVR32_SYNTAX_PASR_H,
  AVR32_SYNTAX_PAVG_SH,
  AVR32_SYNTAX_PAVG_UB,
  AVR32_SYNTAX_PLSL_B,
  AVR32_SYNTAX_PLSL_H,
  AVR32_SYNTAX_PLSR_B,
  AVR32_SYNTAX_PLSR_H,
  AVR32_SYNTAX_PMAX_SH,
  AVR32_SYNTAX_PMAX_UB,
  AVR32_SYNTAX_PMIN_SH,
  AVR32_SYNTAX_PMIN_UB,
  AVR32_SYNTAX_POPJC,
  AVR32_SYNTAX_POPM,
  AVR32_SYNTAX_POPM_E,
  AVR32_SYNTAX_PREF,
  AVR32_SYNTAX_PSAD,
  AVR32_SYNTAX_PSUB_B,
  AVR32_SYNTAX_PSUB_H,
  AVR32_SYNTAX_PSUBADD_H,
  AVR32_SYNTAX_PSUBADDH_SH,
  AVR32_SYNTAX_PSUBADDS_SH,
  AVR32_SYNTAX_PSUBADDS_UH,
  AVR32_SYNTAX_PSUBH_SH,
  AVR32_SYNTAX_PSUBH_UB,
  AVR32_SYNTAX_PSUBS_SB,
  AVR32_SYNTAX_PSUBS_SH,
  AVR32_SYNTAX_PSUBS_UB,
  AVR32_SYNTAX_PSUBS_UH,
  AVR32_SYNTAX_PSUBX_H,
  AVR32_SYNTAX_PSUBXH_SH,
  AVR32_SYNTAX_PSUBXS_SH,
  AVR32_SYNTAX_PSUBXS_UH,
  AVR32_SYNTAX_PUNPCKSB_H,
  AVR32_SYNTAX_PUNPCKUB_H,
  AVR32_SYNTAX_PUSHJC,
  AVR32_SYNTAX_PUSHM,
  AVR32_SYNTAX_PUSHM_E,
  AVR32_SYNTAX_RCALL1,
  AVR32_SYNTAX_RCALL2,
  AVR32_SYNTAX_RETEQ,
  AVR32_SYNTAX_RETNE,
  AVR32_SYNTAX_RETCC,
  AVR32_SYNTAX_RETCS,
  AVR32_SYNTAX_RETGE,
  AVR32_SYNTAX_RETLT,
  AVR32_SYNTAX_RETMI,
  AVR32_SYNTAX_RETPL,
  AVR32_SYNTAX_RETLS,
  AVR32_SYNTAX_RETGT,
  AVR32_SYNTAX_RETLE,
  AVR32_SYNTAX_RETHI,
  AVR32_SYNTAX_RETVS,
  AVR32_SYNTAX_RETVC,
  AVR32_SYNTAX_RETQS,
  AVR32_SYNTAX_RETAL,
  AVR32_SYNTAX_RETHS,
  AVR32_SYNTAX_RETLO,
  AVR32_SYNTAX_RETD,
  AVR32_SYNTAX_RETE,
  AVR32_SYNTAX_RETJ,
  AVR32_SYNTAX_RETS,
  AVR32_SYNTAX_RJMP,
  AVR32_SYNTAX_ROL,
  AVR32_SYNTAX_ROR,
  AVR32_SYNTAX_RSUB1,
  AVR32_SYNTAX_RSUB2,
  AVR32_SYNTAX_SATADD_H,
  AVR32_SYNTAX_SATADD_W,
  AVR32_SYNTAX_SATRNDS,
  AVR32_SYNTAX_SATRNDU,
  AVR32_SYNTAX_SATS,
  AVR32_SYNTAX_SATSUB_H,
  AVR32_SYNTAX_SATSUB_W1,
  AVR32_SYNTAX_SATSUB_W2,
  AVR32_SYNTAX_SATU,
  AVR32_SYNTAX_SBC,
  AVR32_SYNTAX_SBR,
  AVR32_SYNTAX_SCALL,
  AVR32_SYNTAX_SCR,
  AVR32_SYNTAX_SLEEP,
  AVR32_SYNTAX_SREQ,
  AVR32_SYNTAX_SRNE,
  AVR32_SYNTAX_SRCC,
  AVR32_SYNTAX_SRCS,
  AVR32_SYNTAX_SRGE,
  AVR32_SYNTAX_SRLT,
  AVR32_SYNTAX_SRMI,
  AVR32_SYNTAX_SRPL,
  AVR32_SYNTAX_SRLS,
  AVR32_SYNTAX_SRGT,
  AVR32_SYNTAX_SRLE,
  AVR32_SYNTAX_SRHI,
  AVR32_SYNTAX_SRVS,
  AVR32_SYNTAX_SRVC,
  AVR32_SYNTAX_SRQS,
  AVR32_SYNTAX_SRAL,
  AVR32_SYNTAX_SRHS,
  AVR32_SYNTAX_SRLO,
  AVR32_SYNTAX_SSRF,
  AVR32_SYNTAX_ST_B1,
  AVR32_SYNTAX_ST_B2,
  AVR32_SYNTAX_ST_B5,
  AVR32_SYNTAX_ST_B3,
  AVR32_SYNTAX_ST_B4,
  AVR32_SYNTAX_ST_D1,
  AVR32_SYNTAX_ST_D2,
  AVR32_SYNTAX_ST_D3,
  AVR32_SYNTAX_ST_D5,
  AVR32_SYNTAX_ST_D4,
  AVR32_SYNTAX_ST_H1,
  AVR32_SYNTAX_ST_H2,
  AVR32_SYNTAX_ST_H5,
  AVR32_SYNTAX_ST_H3,
  AVR32_SYNTAX_ST_H4,
  AVR32_SYNTAX_ST_W1,
  AVR32_SYNTAX_ST_W2,
  AVR32_SYNTAX_ST_W5,
  AVR32_SYNTAX_ST_W3,
  AVR32_SYNTAX_ST_W4,
  AVR32_SYNTAX_STC_D1,
  AVR32_SYNTAX_STC_D2,
  AVR32_SYNTAX_STC_D3,
  AVR32_SYNTAX_STC_W1,
  AVR32_SYNTAX_STC_W2,
  AVR32_SYNTAX_STC_W3,
  AVR32_SYNTAX_STC0_D,
  AVR32_SYNTAX_STC0_W,
  AVR32_SYNTAX_STCM_D,
  AVR32_SYNTAX_STCM_D_PU,
  AVR32_SYNTAX_STCM_W,
  AVR32_SYNTAX_STCM_W_PU,
  AVR32_SYNTAX_STCOND,
  AVR32_SYNTAX_STDSP,
  AVR32_SYNTAX_STHH_W2,
  AVR32_SYNTAX_STHH_W1,
  AVR32_SYNTAX_STM,
  AVR32_SYNTAX_STM_PU,
  AVR32_SYNTAX_STMTS,
  AVR32_SYNTAX_STMTS_PU,
  AVR32_SYNTAX_STSWP_H,
  AVR32_SYNTAX_STSWP_W,
  AVR32_SYNTAX_SUB1,
  AVR32_SYNTAX_SUB2,
  AVR32_SYNTAX_SUB5,
  AVR32_SYNTAX_SUB3_SP,
  AVR32_SYNTAX_SUB3,
  AVR32_SYNTAX_SUB4,
  AVR32_SYNTAX_SUBEQ,
  AVR32_SYNTAX_SUBNE,
  AVR32_SYNTAX_SUBCC,
  AVR32_SYNTAX_SUBCS,
  AVR32_SYNTAX_SUBGE,
  AVR32_SYNTAX_SUBLT,
  AVR32_SYNTAX_SUBMI,
  AVR32_SYNTAX_SUBPL,
  AVR32_SYNTAX_SUBLS,
  AVR32_SYNTAX_SUBGT,
  AVR32_SYNTAX_SUBLE,
  AVR32_SYNTAX_SUBHI,
  AVR32_SYNTAX_SUBVS,
  AVR32_SYNTAX_SUBVC,
  AVR32_SYNTAX_SUBQS,
  AVR32_SYNTAX_SUBAL,
  AVR32_SYNTAX_SUBHS,
  AVR32_SYNTAX_SUBLO,
  AVR32_SYNTAX_SUBFEQ,
  AVR32_SYNTAX_SUBFNE,
  AVR32_SYNTAX_SUBFCC,
  AVR32_SYNTAX_SUBFCS,
  AVR32_SYNTAX_SUBFGE,
  AVR32_SYNTAX_SUBFLT,
  AVR32_SYNTAX_SUBFMI,
  AVR32_SYNTAX_SUBFPL,
  AVR32_SYNTAX_SUBFLS,
  AVR32_SYNTAX_SUBFGT,
  AVR32_SYNTAX_SUBFLE,
  AVR32_SYNTAX_SUBFHI,
  AVR32_SYNTAX_SUBFVS,
  AVR32_SYNTAX_SUBFVC,
  AVR32_SYNTAX_SUBFQS,
  AVR32_SYNTAX_SUBFAL,
  AVR32_SYNTAX_SUBFHS,
  AVR32_SYNTAX_SUBFLO,
  AVR32_SYNTAX_SUBHH_W,
  AVR32_SYNTAX_SWAP_B,
  AVR32_SYNTAX_SWAP_BH,
  AVR32_SYNTAX_SWAP_H,
  AVR32_SYNTAX_SYNC,
  AVR32_SYNTAX_TLBR,
  AVR32_SYNTAX_TLBS,
  AVR32_SYNTAX_TLBW,
  AVR32_SYNTAX_TNBZ,
  AVR32_SYNTAX_TST,
  AVR32_SYNTAX_XCHG,
  AVR32_SYNTAX_MEMC,
  AVR32_SYNTAX_MEMS,
  AVR32_SYNTAX_MEMT,
  AVR32_SYNTAX_FADD_S,
  AVR32_SYNTAX_FADD_D,
  AVR32_SYNTAX_FSUB_S,
  AVR32_SYNTAX_FSUB_D,
  AVR32_SYNTAX_FMAC_S,
  AVR32_SYNTAX_FMAC_D,
  AVR32_SYNTAX_FNMAC_S,
  AVR32_SYNTAX_FNMAC_D,
  AVR32_SYNTAX_FMSC_S,
  AVR32_SYNTAX_FMSC_D,
  AVR32_SYNTAX_FNMSC_S,
  AVR32_SYNTAX_FNMSC_D,
  AVR32_SYNTAX_FMUL_S,
  AVR32_SYNTAX_FMUL_D,
  AVR32_SYNTAX_FNMUL_S,
  AVR32_SYNTAX_FNMUL_D,
  AVR32_SYNTAX_FNEG_S,
  AVR32_SYNTAX_FNEG_D,
  AVR32_SYNTAX_FABS_S,
  AVR32_SYNTAX_FABS_D,
  AVR32_SYNTAX_FCMP_S,
  AVR32_SYNTAX_FCMP_D,
  AVR32_SYNTAX_FMOV1_S,
  AVR32_SYNTAX_FMOV1_D,
  AVR32_SYNTAX_FMOV2_S,
  AVR32_SYNTAX_FMOV2_D,
  AVR32_SYNTAX_FMOV3_S,
  AVR32_SYNTAX_FMOV3_D,
  AVR32_SYNTAX_FCASTS_D,
  AVR32_SYNTAX_FCASTD_S,
  AVR32_SYNTAX_LDA_W,
  AVR32_SYNTAX_CALL,
  AVR32_SYNTAX_PICOSVMAC0,
  AVR32_SYNTAX_PICOSVMAC1,
  AVR32_SYNTAX_PICOSVMAC2,
  AVR32_SYNTAX_PICOSVMUL0,
  AVR32_SYNTAX_PICOSVMUL1,
  AVR32_SYNTAX_PICOSVMUL2,
  AVR32_SYNTAX_PICOVMAC0,
  AVR32_SYNTAX_PICOVMAC1,
  AVR32_SYNTAX_PICOVMAC2,
  AVR32_SYNTAX_PICOVMUL0,
  AVR32_SYNTAX_PICOVMUL1,
  AVR32_SYNTAX_PICOVMUL2,
  AVR32_SYNTAX_PICOLD_D2,
  AVR32_SYNTAX_PICOLD_D3,
  AVR32_SYNTAX_PICOLD_D1,
  AVR32_SYNTAX_PICOLD_W2,
  AVR32_SYNTAX_PICOLD_W3,
  AVR32_SYNTAX_PICOLD_W1,
  AVR32_SYNTAX_PICOLDM_D,
  AVR32_SYNTAX_PICOLDM_D_PU,
  AVR32_SYNTAX_PICOLDM_W,
  AVR32_SYNTAX_PICOLDM_W_PU,
  AVR32_SYNTAX_PICOMV_D1,
  AVR32_SYNTAX_PICOMV_D2,
  AVR32_SYNTAX_PICOMV_W1,
  AVR32_SYNTAX_PICOMV_W2,
  AVR32_SYNTAX_PICOST_D2,
  AVR32_SYNTAX_PICOST_D3,
  AVR32_SYNTAX_PICOST_D1,
  AVR32_SYNTAX_PICOST_W2,
  AVR32_SYNTAX_PICOST_W3,
  AVR32_SYNTAX_PICOST_W1,
  AVR32_SYNTAX_PICOSTM_D,
  AVR32_SYNTAX_PICOSTM_D_PU,
  AVR32_SYNTAX_PICOSTM_W,
  AVR32_SYNTAX_PICOSTM_W_PU,
  AVR32_SYNTAX__END_
};
#define AVR32_NR_SYNTAX AVR32_SYNTAX__END_

enum avr32_alias_type
  {
    AVR32_ALIAS_FMAC_S,
    AVR32_ALIAS_FMAC_D,
    AVR32_ALIAS_FNMAC_S,
    AVR32_ALIAS_FNMAC_D,
    AVR32_ALIAS_FMSC_S,
    AVR32_ALIAS_FMSC_D,
    AVR32_ALIAS_FNMSC_S,
    AVR32_ALIAS_FNMSC_D,
    AVR32_ALIAS_FADD_S,
    AVR32_ALIAS_FADD_D,
    AVR32_ALIAS_FSUB_S,
    AVR32_ALIAS_FSUB_D,
    AVR32_ALIAS_FMUL_S,
    AVR32_ALIAS_FMUL_D,
    AVR32_ALIAS_FNMUL_S,
    AVR32_ALIAS_FNMUL_D,
    AVR32_ALIAS_FNEG_S,
    AVR32_ALIAS_FNEG_D,
    AVR32_ALIAS_FABS_S,
    AVR32_ALIAS_FABS_D,
    AVR32_ALIAS_FCMP_S,
    AVR32_ALIAS_FCMP_D,
    AVR32_ALIAS_FMOV1_S,
    AVR32_ALIAS_FMOV1_D,
    AVR32_ALIAS_FMOV2_S,
    AVR32_ALIAS_FMOV2_D,
    AVR32_ALIAS_FMOV3_S,
    AVR32_ALIAS_FMOV3_D,
    AVR32_ALIAS_FCASTS_D,
    AVR32_ALIAS_FCASTD_S,
    AVR32_ALIAS_PICOSVMAC0,
    AVR32_ALIAS_PICOSVMAC1,
    AVR32_ALIAS_PICOSVMAC2,
    AVR32_ALIAS_PICOSVMUL0,
    AVR32_ALIAS_PICOSVMUL1,
    AVR32_ALIAS_PICOSVMUL2,
    AVR32_ALIAS_PICOVMAC0,
    AVR32_ALIAS_PICOVMAC1,
    AVR32_ALIAS_PICOVMAC2,
    AVR32_ALIAS_PICOVMUL0,
    AVR32_ALIAS_PICOVMUL1,
    AVR32_ALIAS_PICOVMUL2,
    AVR32_ALIAS_PICOLD_D1,
    AVR32_ALIAS_PICOLD_D2,
    AVR32_ALIAS_PICOLD_D3,
    AVR32_ALIAS_PICOLD_W1,
    AVR32_ALIAS_PICOLD_W2,
    AVR32_ALIAS_PICOLD_W3,
    AVR32_ALIAS_PICOLDM_D,
    AVR32_ALIAS_PICOLDM_D_PU,
    AVR32_ALIAS_PICOLDM_W,
    AVR32_ALIAS_PICOLDM_W_PU,
    AVR32_ALIAS_PICOMV_D1,
    AVR32_ALIAS_PICOMV_D2,
    AVR32_ALIAS_PICOMV_W1,
    AVR32_ALIAS_PICOMV_W2,
    AVR32_ALIAS_PICOST_D1,
    AVR32_ALIAS_PICOST_D2,
    AVR32_ALIAS_PICOST_D3,
    AVR32_ALIAS_PICOST_W1,
    AVR32_ALIAS_PICOST_W2,
    AVR32_ALIAS_PICOST_W3,
    AVR32_ALIAS_PICOSTM_D,
    AVR32_ALIAS_PICOSTM_D_PU,
    AVR32_ALIAS_PICOSTM_W,
    AVR32_ALIAS_PICOSTM_W_PU,
    AVR32_ALIAS__END_
  };
#define AVR32_NR_ALIAS AVR32_ALIAS__END_

enum avr32_mnemonic_type
{
  AVR32_MNEMONIC_ABS,
  AVR32_MNEMONIC_ACALL,
  AVR32_MNEMONIC_ACR,
  AVR32_MNEMONIC_ADC,
  AVR32_MNEMONIC_ADD,
  AVR32_MNEMONIC_ADDABS,
  AVR32_MNEMONIC_ADDHH_W,
  AVR32_MNEMONIC_AND,
  AVR32_MNEMONIC_ANDH,
  AVR32_MNEMONIC_ANDL,
  AVR32_MNEMONIC_ANDN,
  AVR32_MNEMONIC_ASR,
  AVR32_MNEMONIC_BFEXTS,
  AVR32_MNEMONIC_BFEXTU,
  AVR32_MNEMONIC_BFINS,
  AVR32_MNEMONIC_BLD,
  AVR32_MNEMONIC_BREQ,
  AVR32_MNEMONIC_BRNE,
  AVR32_MNEMONIC_BRCC,
  AVR32_MNEMONIC_BRCS,
  AVR32_MNEMONIC_BRGE,
  AVR32_MNEMONIC_BRLT,
  AVR32_MNEMONIC_BRMI,
  AVR32_MNEMONIC_BRPL,
  AVR32_MNEMONIC_BRHS,
  AVR32_MNEMONIC_BRLO,
  AVR32_MNEMONIC_BRLS,
  AVR32_MNEMONIC_BRGT,
  AVR32_MNEMONIC_BRLE,
  AVR32_MNEMONIC_BRHI,
  AVR32_MNEMONIC_BRVS,
  AVR32_MNEMONIC_BRVC,
  AVR32_MNEMONIC_BRQS,
  AVR32_MNEMONIC_BRAL,
  AVR32_MNEMONIC_BREAKPOINT,
  AVR32_MNEMONIC_BREV,
  AVR32_MNEMONIC_BST,
  AVR32_MNEMONIC_CACHE,
  AVR32_MNEMONIC_CASTS_B,
  AVR32_MNEMONIC_CASTS_H,
  AVR32_MNEMONIC_CASTU_B,
  AVR32_MNEMONIC_CASTU_H,
  AVR32_MNEMONIC_CBR,
  AVR32_MNEMONIC_CLZ,
  AVR32_MNEMONIC_COM,
  AVR32_MNEMONIC_COP,
  AVR32_MNEMONIC_CP_B,
  AVR32_MNEMONIC_CP_H,
  AVR32_MNEMONIC_CP_W,
  AVR32_MNEMONIC_CP,
  AVR32_MNEMONIC_CPC,
  AVR32_MNEMONIC_CSRF,
  AVR32_MNEMONIC_CSRFCZ,
  AVR32_MNEMONIC_DIVS,
  AVR32_MNEMONIC_DIVU,
  AVR32_MNEMONIC_EOR,
  AVR32_MNEMONIC_EORL,
  AVR32_MNEMONIC_EORH,
  AVR32_MNEMONIC_FRS,
  AVR32_MNEMONIC_ICALL,
  AVR32_MNEMONIC_INCJOSP,
  AVR32_MNEMONIC_LD_D,
  AVR32_MNEMONIC_LD_SB,
  AVR32_MNEMONIC_LD_UB,
  AVR32_MNEMONIC_LD_SH,
  AVR32_MNEMONIC_LD_UH,
  AVR32_MNEMONIC_LD_W,
  AVR32_MNEMONIC_LDC_D,
  AVR32_MNEMONIC_LDC_W,
  AVR32_MNEMONIC_LDC0_D,
  AVR32_MNEMONIC_LDC0_W,
  AVR32_MNEMONIC_LDCM_D,
  AVR32_MNEMONIC_LDCM_W,
  AVR32_MNEMONIC_LDDPC,
  AVR32_MNEMONIC_LDDSP,
  AVR32_MNEMONIC_LDINS_B,
  AVR32_MNEMONIC_LDINS_H,
  AVR32_MNEMONIC_LDM,
  AVR32_MNEMONIC_LDMTS,
  AVR32_MNEMONIC_LDSWP_SH,
  AVR32_MNEMONIC_LDSWP_UH,
  AVR32_MNEMONIC_LDSWP_W,
  AVR32_MNEMONIC_LSL,
  AVR32_MNEMONIC_LSR,
  AVR32_MNEMONIC_MAC,
  AVR32_MNEMONIC_MACHH_D,
  AVR32_MNEMONIC_MACHH_W,
  AVR32_MNEMONIC_MACS_D,
  AVR32_MNEMONIC_MACSATHH_W,
  AVR32_MNEMONIC_MACU_D,
  AVR32_MNEMONIC_MACWH_D,
  AVR32_MNEMONIC_MAX,
  AVR32_MNEMONIC_MCALL,
  AVR32_MNEMONIC_MFDR,
  AVR32_MNEMONIC_MFSR,
  AVR32_MNEMONIC_MIN,
  AVR32_MNEMONIC_MOV,
  AVR32_MNEMONIC_MOVEQ,
  AVR32_MNEMONIC_MOVNE,
  AVR32_MNEMONIC_MOVCC,
  AVR32_MNEMONIC_MOVCS,
  AVR32_MNEMONIC_MOVGE,
  AVR32_MNEMONIC_MOVLT,
  AVR32_MNEMONIC_MOVMI,
  AVR32_MNEMONIC_MOVPL,
  AVR32_MNEMONIC_MOVLS,
  AVR32_MNEMONIC_MOVGT,
  AVR32_MNEMONIC_MOVLE,
  AVR32_MNEMONIC_MOVHI,
  AVR32_MNEMONIC_MOVVS,
  AVR32_MNEMONIC_MOVVC,
  AVR32_MNEMONIC_MOVQS,
  AVR32_MNEMONIC_MOVAL,
  AVR32_MNEMONIC_MOVHS,
  AVR32_MNEMONIC_MOVLO,
  AVR32_MNEMONIC_MTDR,
  AVR32_MNEMONIC_MTSR,
  AVR32_MNEMONIC_MUL,
  AVR32_MNEMONIC_MULHH_W,
  AVR32_MNEMONIC_MULNHH_W,
  AVR32_MNEMONIC_MULNWH_D,
  AVR32_MNEMONIC_MULS_D,
  AVR32_MNEMONIC_MULSATHH_H,
  AVR32_MNEMONIC_MULSATHH_W,
  AVR32_MNEMONIC_MULSATRNDHH_H,
  AVR32_MNEMONIC_MULSATRNDWH_W,
  AVR32_MNEMONIC_MULSATWH_W,
  AVR32_MNEMONIC_MULU_D,
  AVR32_MNEMONIC_MULWH_D,
  AVR32_MNEMONIC_MUSFR,
  AVR32_MNEMONIC_MUSTR,
  AVR32_MNEMONIC_MVCR_D,
  AVR32_MNEMONIC_MVCR_W,
  AVR32_MNEMONIC_MVRC_D,
  AVR32_MNEMONIC_MVRC_W,
  AVR32_MNEMONIC_NEG,
  AVR32_MNEMONIC_NOP,
  AVR32_MNEMONIC_OR,
  AVR32_MNEMONIC_ORH,
  AVR32_MNEMONIC_ORL,
  AVR32_MNEMONIC_PABS_SB,
  AVR32_MNEMONIC_PABS_SH,
  AVR32_MNEMONIC_PACKSH_SB,
  AVR32_MNEMONIC_PACKSH_UB,
  AVR32_MNEMONIC_PACKW_SH,
  AVR32_MNEMONIC_PADD_B,
  AVR32_MNEMONIC_PADD_H,
  AVR32_MNEMONIC_PADDH_SH,
  AVR32_MNEMONIC_PADDH_UB,
  AVR32_MNEMONIC_PADDS_SB,
  AVR32_MNEMONIC_PADDS_SH,
  AVR32_MNEMONIC_PADDS_UB,
  AVR32_MNEMONIC_PADDS_UH,
  AVR32_MNEMONIC_PADDSUB_H,
  AVR32_MNEMONIC_PADDSUBH_SH,
  AVR32_MNEMONIC_PADDSUBS_SH,
  AVR32_MNEMONIC_PADDSUBS_UH,
  AVR32_MNEMONIC_PADDX_H,
  AVR32_MNEMONIC_PADDXH_SH,
  AVR32_MNEMONIC_PADDXS_SH,
  AVR32_MNEMONIC_PADDXS_UH,
  AVR32_MNEMONIC_PASR_B,
  AVR32_MNEMONIC_PASR_H,
  AVR32_MNEMONIC_PAVG_SH,
  AVR32_MNEMONIC_PAVG_UB,
  AVR32_MNEMONIC_PLSL_B,
  AVR32_MNEMONIC_PLSL_H,
  AVR32_MNEMONIC_PLSR_B,
  AVR32_MNEMONIC_PLSR_H,
  AVR32_MNEMONIC_PMAX_SH,
  AVR32_MNEMONIC_PMAX_UB,
  AVR32_MNEMONIC_PMIN_SH,
  AVR32_MNEMONIC_PMIN_UB,
  AVR32_MNEMONIC_POPJC,
  AVR32_MNEMONIC_POPM,
  AVR32_MNEMONIC_PREF,
  AVR32_MNEMONIC_PSAD,
  AVR32_MNEMONIC_PSUB_B,
  AVR32_MNEMONIC_PSUB_H,
  AVR32_MNEMONIC_PSUBADD_H,
  AVR32_MNEMONIC_PSUBADDH_SH,
  AVR32_MNEMONIC_PSUBADDS_SH,
  AVR32_MNEMONIC_PSUBADDS_UH,
  AVR32_MNEMONIC_PSUBH_SH,
  AVR32_MNEMONIC_PSUBH_UB,
  AVR32_MNEMONIC_PSUBS_SB,
  AVR32_MNEMONIC_PSUBS_SH,
  AVR32_MNEMONIC_PSUBS_UB,
  AVR32_MNEMONIC_PSUBS_UH,
  AVR32_MNEMONIC_PSUBX_H,
  AVR32_MNEMONIC_PSUBXH_SH,
  AVR32_MNEMONIC_PSUBXS_SH,
  AVR32_MNEMONIC_PSUBXS_UH,
  AVR32_MNEMONIC_PUNPCKSB_H,
  AVR32_MNEMONIC_PUNPCKUB_H,
  AVR32_MNEMONIC_PUSHJC,
  AVR32_MNEMONIC_PUSHM,
  AVR32_MNEMONIC_RCALL,
  AVR32_MNEMONIC_RETEQ,
  AVR32_MNEMONIC_RETNE,
  AVR32_MNEMONIC_RETCC,
  AVR32_MNEMONIC_RETCS,
  AVR32_MNEMONIC_RETGE,
  AVR32_MNEMONIC_RETLT,
  AVR32_MNEMONIC_RETMI,
  AVR32_MNEMONIC_RETPL,
  AVR32_MNEMONIC_RETLS,
  AVR32_MNEMONIC_RETGT,
  AVR32_MNEMONIC_RETLE,
  AVR32_MNEMONIC_RETHI,
  AVR32_MNEMONIC_RETVS,
  AVR32_MNEMONIC_RETVC,
  AVR32_MNEMONIC_RETQS,
  AVR32_MNEMONIC_RETAL,
  AVR32_MNEMONIC_RETHS,
  AVR32_MNEMONIC_RETLO,
  AVR32_MNEMONIC_RET,
  AVR32_MNEMONIC_RETD,
  AVR32_MNEMONIC_RETE,
  AVR32_MNEMONIC_RETJ,
  AVR32_MNEMONIC_RETS,
  AVR32_MNEMONIC_RJMP,
  AVR32_MNEMONIC_ROL,
  AVR32_MNEMONIC_ROR,
  AVR32_MNEMONIC_RSUB,
  AVR32_MNEMONIC_SATADD_H,
  AVR32_MNEMONIC_SATADD_W,
  AVR32_MNEMONIC_SATRNDS,
  AVR32_MNEMONIC_SATRNDU,
  AVR32_MNEMONIC_SATS,
  AVR32_MNEMONIC_SATSUB_H,
  AVR32_MNEMONIC_SATSUB_W,
  AVR32_MNEMONIC_SATU,
  AVR32_MNEMONIC_SBC,
  AVR32_MNEMONIC_SBR,
  AVR32_MNEMONIC_SCALL,
  AVR32_MNEMONIC_SCR,
  AVR32_MNEMONIC_SLEEP,
  AVR32_MNEMONIC_SREQ,
  AVR32_MNEMONIC_SRNE,
  AVR32_MNEMONIC_SRCC,
  AVR32_MNEMONIC_SRCS,
  AVR32_MNEMONIC_SRGE,
  AVR32_MNEMONIC_SRLT,
  AVR32_MNEMONIC_SRMI,
  AVR32_MNEMONIC_SRPL,
  AVR32_MNEMONIC_SRLS,
  AVR32_MNEMONIC_SRGT,
  AVR32_MNEMONIC_SRLE,
  AVR32_MNEMONIC_SRHI,
  AVR32_MNEMONIC_SRVS,
  AVR32_MNEMONIC_SRVC,
  AVR32_MNEMONIC_SRQS,
  AVR32_MNEMONIC_SRAL,
  AVR32_MNEMONIC_SRHS,
  AVR32_MNEMONIC_SRLO,
  AVR32_MNEMONIC_SSRF,
  AVR32_MNEMONIC_ST_B,
  AVR32_MNEMONIC_ST_D,
  AVR32_MNEMONIC_ST_H,
  AVR32_MNEMONIC_ST_W,
  AVR32_MNEMONIC_STC_D,
  AVR32_MNEMONIC_STC_W,
  AVR32_MNEMONIC_STC0_D,
  AVR32_MNEMONIC_STC0_W,
  AVR32_MNEMONIC_STCM_D,
  AVR32_MNEMONIC_STCM_W,
  AVR32_MNEMONIC_STCOND,
  AVR32_MNEMONIC_STDSP,
  AVR32_MNEMONIC_STHH_W,
  AVR32_MNEMONIC_STM,
  AVR32_MNEMONIC_STMTS,
  AVR32_MNEMONIC_STSWP_H,
  AVR32_MNEMONIC_STSWP_W,
  AVR32_MNEMONIC_SUB,
  AVR32_MNEMONIC_SUBEQ,
  AVR32_MNEMONIC_SUBNE,
  AVR32_MNEMONIC_SUBCC,
  AVR32_MNEMONIC_SUBCS,
  AVR32_MNEMONIC_SUBGE,
  AVR32_MNEMONIC_SUBLT,
  AVR32_MNEMONIC_SUBMI,
  AVR32_MNEMONIC_SUBPL,
  AVR32_MNEMONIC_SUBLS,
  AVR32_MNEMONIC_SUBGT,
  AVR32_MNEMONIC_SUBLE,
  AVR32_MNEMONIC_SUBHI,
  AVR32_MNEMONIC_SUBVS,
  AVR32_MNEMONIC_SUBVC,
  AVR32_MNEMONIC_SUBQS,
  AVR32_MNEMONIC_SUBAL,
  AVR32_MNEMONIC_SUBHS,
  AVR32_MNEMONIC_SUBLO,
  AVR32_MNEMONIC_SUBFEQ,
  AVR32_MNEMONIC_SUBFNE,
  AVR32_MNEMONIC_SUBFCC,
  AVR32_MNEMONIC_SUBFCS,
  AVR32_MNEMONIC_SUBFGE,
  AVR32_MNEMONIC_SUBFLT,
  AVR32_MNEMONIC_SUBFMI,
  AVR32_MNEMONIC_SUBFPL,
  AVR32_MNEMONIC_SUBFLS,
  AVR32_MNEMONIC_SUBFGT,
  AVR32_MNEMONIC_SUBFLE,
  AVR32_MNEMONIC_SUBFHI,
  AVR32_MNEMONIC_SUBFVS,
  AVR32_MNEMONIC_SUBFVC,
  AVR32_MNEMONIC_SUBFQS,
  AVR32_MNEMONIC_SUBFAL,
  AVR32_MNEMONIC_SUBFHS,
  AVR32_MNEMONIC_SUBFLO,
  AVR32_MNEMONIC_SUBHH_W,
  AVR32_MNEMONIC_SWAP_B,
  AVR32_MNEMONIC_SWAP_BH,
  AVR32_MNEMONIC_SWAP_H,
  AVR32_MNEMONIC_SYNC,
  AVR32_MNEMONIC_TLBR,
  AVR32_MNEMONIC_TLBS,
  AVR32_MNEMONIC_TLBW,
  AVR32_MNEMONIC_TNBZ,
  AVR32_MNEMONIC_TST,
  AVR32_MNEMONIC_XCHG,
  AVR32_MNEMONIC_MEMC,
  AVR32_MNEMONIC_MEMS,
  AVR32_MNEMONIC_MEMT,
  AVR32_MNEMONIC_FADD_S,
  AVR32_MNEMONIC_FADD_D,
  AVR32_MNEMONIC_FSUB_S,
  AVR32_MNEMONIC_FSUB_D,
  AVR32_MNEMONIC_FMAC_S,
  AVR32_MNEMONIC_FMAC_D,
  AVR32_MNEMONIC_FNMAC_S,
  AVR32_MNEMONIC_FNMAC_D,
  AVR32_MNEMONIC_FMSC_S,
  AVR32_MNEMONIC_FMSC_D,
  AVR32_MNEMONIC_FNMSC_S,
  AVR32_MNEMONIC_FNMSC_D,
  AVR32_MNEMONIC_FMUL_S,
  AVR32_MNEMONIC_FMUL_D,
  AVR32_MNEMONIC_FNMUL_S,
  AVR32_MNEMONIC_FNMUL_D,
  AVR32_MNEMONIC_FNEG_S,
  AVR32_MNEMONIC_FNEG_D,
  AVR32_MNEMONIC_FABS_S,
  AVR32_MNEMONIC_FABS_D,
  AVR32_MNEMONIC_FCMP_S,
  AVR32_MNEMONIC_FCMP_D,
  AVR32_MNEMONIC_FMOV_S,
  AVR32_MNEMONIC_FMOV_D,
  AVR32_MNEMONIC_FCASTS_D,
  AVR32_MNEMONIC_FCASTD_S,
  /* AVR32_MNEMONIC_FLD_S,
     AVR32_MNEMONIC_FLD_D,
     AVR32_MNEMONIC_FST_S,
     AVR32_MNEMONIC_FST_D, */
  AVR32_MNEMONIC_LDA_W,
  AVR32_MNEMONIC_CALL,
  AVR32_MNEMONIC_PICOSVMAC,
  AVR32_MNEMONIC_PICOSVMUL,
  AVR32_MNEMONIC_PICOVMAC,
  AVR32_MNEMONIC_PICOVMUL,
  AVR32_MNEMONIC_PICOLD_D,
  AVR32_MNEMONIC_PICOLD_W,
  AVR32_MNEMONIC_PICOLDM_D,
  AVR32_MNEMONIC_PICOLDM_W,
  AVR32_MNEMONIC_PICOMV_D,
  AVR32_MNEMONIC_PICOMV_W,
  AVR32_MNEMONIC_PICOST_D,
  AVR32_MNEMONIC_PICOST_W,
  AVR32_MNEMONIC_PICOSTM_D,
  AVR32_MNEMONIC_PICOSTM_W,
  AVR32_MNEMONIC__END_
};
#define AVR32_NR_MNEMONICS AVR32_MNEMONIC__END_

enum avr32_syntax_parser
  {
    AVR32_PARSER_NORMAL,
    AVR32_PARSER_ALIAS,
    AVR32_PARSER_LDA,
    AVR32_PARSER_CALL,
    AVR32_PARSER__END_
  };
#define AVR32_NR_PARSERS AVR32_PARSER__END_
